Form Example
===============================================================================

:download:`form.enaml <../../../examples/widgets/form.enaml>`

.. literalinclude:: ../../../examples/widgets/form.enaml
    :language: python

::

 $ enaml-run form.enaml

.. image:: images/form.png
